@@ -33,13 +33,3 @@ setClass("LowRankMatrix",
     contains="DelayedMatrix",
     representation(seed="LowRankMatrixSeed")
 )
-
-#' @export
-setClass("ResidualMatrixSeed", slots=c(.matrix="ANY", Q="matrix", Qty="matrix", transposed="logical", centered="logical"))
-
-#' @export
-#' @importClassesFrom DelayedArray DelayedMatrix
-setClass("ResidualMatrix",
-    contains="DelayedMatrix",
-    representation(seed="ResidualMatrixSeed")
-)
